# OGO Clients Utils | Python == 3.9.10

> This project provides utilities for my daily use.

## Installation

```shell
python3 -m pip install ogo-utils
```

## Set config
```shell
poetry config pypi-token.pypi pypi-token
```